// plist.js - Handle Apple plist files and structures
// by Rene Laterveer (e-mail: rene@smsmac.com)


function parsePListFile(plistFile) {
	try {
		// Instantiate a DOM object.
		var xmldoc = new ActiveXObject("msxml2.DOMDocument.3.0");
		xmldoc.async = false;
		xmldoc.resolveExternals = false;
		xmldoc.validateOnParse = false;
		
		// Load an XML file into the DOM instance.
		xmldoc.load(plistFile);
		return parsePList(xmldoc);
	} catch(e) {
		return new Array();
	}

}

function parsePList(plistXML) {
	var key_value = null;
	try {
		var oNodes;
		oNodes = plistXML.selectNodes("//dict[0]/*");
		var i;
		var plistArray = new Array();
		for (i=0; i<oNodes.length; i++) {
			oNode = oNodes.nextNode;
			if (oNode != null) {
				if (oNode.nodeName.toLowerCase()== "key") {
					var key = oNode.nodeTypedValue;
					var value = oNodes.nextNode;
					if (value.nodeName.toLowerCase() != "array") {
						key_value = value.nodeTypedValue;
					} else {
						// not completly implemented yet
						key_value = new Array();
					}
				}
			}
			if (key_value=="undefined") {
				key_value = null;
			}
			plistArray[key] = key_value;
		}
	} catch(e) {
		return new Array();
	}

	return plistArray;
}

function writePListFile(filename, plist)
{
	var key;
	for (key in plist) {
		var value = new String(plist[key]);
		var type = 'string';
		if (value.match(/[^\d\-\.]/))
			type = 'string';
		if (value.match(/^-?\d+$/))
			type = 'integer';
		if (value.match(/^-?\d*\.\d+$/))
			type = 'real';
	}

	var fs = new ActiveXObject("Scripting.FileSystemObject");

	try
	{
		var newFile = fs.CreateTextFile(filename);
		
		try {
			newFile.WriteLine('<?xml version="1.0" encoding="UTF-8"?>');
			newFile.WriteLine('<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN"');
			newFile.WriteLine('        "http://www.apple.com/DTDs/PropertyList-1.0.dtd">');
			newFile.WriteLine('<plist version="1.0">');
			newFile.WriteLine('<dict>');
			var key;
			for (key in plist) {
				var value = new String(plist[key]);
				newFile.WriteLine("\t<key>" + key+ "</key>");
				var type = 'string';
				if (value.match(/[^\d\-\.]/))
					type = 'string';
				if (value.match(/^-?\d+$/))
					type = 'integer';
				if (value.match(/^-?\d*\.\d+$/))
					type = 'real';
				newFile.WriteLine("\t<" + type + ">" + value + "</" + type + ">");
			}
			newFile.WriteLine('</dict>');
			newFile.WriteLine('</plist>');

		} catch(e) {
		}
		
		finally {
			newFile.Close();
		}

	} catch(e) {
		bug();
	}
		
	finally
	{
		fs = null;
	}
}

